==> guikachu-1.3.1.tar.gz: guikachu-1.3.1/src/widgets/resource-combo.h <==
//$Id: resource-combo.h,v 1.9 2002/06/02 13:53:43 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_WIDGETS_RESOURCE_COMBO_H
#define GUIKACHU_WIDGETS_RESOURCE_COMBO_H

namespace Guikachu
{
    namespace GUI
    {
	class ResourceCombo;
    }
}

#include <gtk--/box.h>
#include <gtk--/combo.h>
#include <gtk--/button.h>
#include "resource.h"
#include "resource-ref.h"
#include "property-editor.h"

namespace Guikachu
{
    namespace GUI
    {
	namespace PropertyEditors
	{
	    class ResourceCombo: public PropertyEditor,
				 public Gtk::HBox
	    {
		ResourceManager *manager;
		Gtk::Combo combo;
		Gtk::Button button_edit;
		
		Resources::Type type;
		
		Properties::ResourceRef &property;
	    public:
		ResourceCombo (ResourceManager         *manager,
			       Resources::Type          type,
			       Properties::ResourceRef &property);
	    private:
		bool update_block;
		void update ();
		
		void add_resource (Resource *res);
		void remove_resource (Resource *res);
		void resource_changed_cb (Resource *res);
		
		void edit_cb ();
		void entry_cb ();
	    };
	}
    }
}

#endif /* !GUIKACHU_WIDGETS_RESOURCE_COMBO_H */

==> guikachu-1.3.2.tar.gz: guikachu-1.3.2/src/widgets/resource-combo.h <==
//$Id: resource-combo.h,v 1.10 2002/09/01 22:45:07 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_WIDGETS_RESOURCE_COMBO_H
#define GUIKACHU_WIDGETS_RESOURCE_COMBO_H

namespace Guikachu
{
    namespace GUI
    {
	class ResourceCombo;
    }
}

#include <gtk--/box.h>
#include <gtk--/combo.h>
#include <gtk--/button.h>
#include "resource.h"
#include "resource-ref.h"
#include "property-editor.h"
#include "property-ops.h"

namespace Guikachu
{
    namespace GUI
    {
	namespace PropertyEditors
	{
	    class ResourceCombo: public PropertyEditor,
				 public Gtk::HBox
	    {
		typedef Properties::ResourceRef          property_t;
		typedef PropChangeOpFactory<std::string> op_factory_t;

		ResourceManager *manager;
		
		Gtk::Combo  combo;
		Gtk::Button button_edit;
		
		Resources::Type type;
		
		property_t                  &property;
		std::auto_ptr<op_factory_t>  op_factory;
		
	    public:
		ResourceCombo (ResourceManager  *manager,
			       Resources::Type   type,
			       property_t       &property,
			       op_factory_t     *op_factory);

	    private:
		bool update_block;
		void update ();
		
		void add_resource (Resource *res);
		void remove_resource (Resource *res);
		void resource_changed_cb (Resource *res);
		
		void edit_cb ();
		void entry_cb ();
	    };
	}
    }
}

#endif /* !GUIKACHU_WIDGETS_RESOURCE_COMBO_H */
